import { Classification } from "../../../models/decisions/classification";
import { DecisionComponent, DecisionModels } from "../decision";
import { Tag } from "../../../models/tag";
import { TemplateResult } from "lit";
import { KeyboardShortcut } from "../../../templates/keyboardShortcut";
/**
 * @description
 * A decision that when made will emit a Classification decision
 * and additional tags in the form of Classification models
 *
 * @slot - Additional content to be displayed in the decision groups title
 *
 * @csspart true-decision-button - Styling selector to target the true decision button
 * @csspart false-decision-button - Styling selector to target the false decision button
 *
 * @event decision
 */
export declare class ClassificationComponent extends DecisionComponent {
    static styles: import("lit").CSSResult[];
    tag: Tag;
    /**
     * A shortcut key that when pressed will trigger a true classification
     * decision to be emitted
     */
    trueShortcut?: string;
    /**
     * A shortcut key that when pressed will trigger a false classification
     * decision to be emitted
     */
    falseShortcut?: string;
    private trueDecisionButton;
    private falseDecisionButton;
    get decisionModels(): Partial<DecisionModels<Classification>>;
    private _decisionModels;
    private get trueKeyboardShortcut();
    private get falseKeyboardShortcut();
    shortcutKeys(): KeyboardShortcut[];
    protected handleShortcutKey(event: KeyboardEvent): void;
    protected isShortcutKey(event: KeyboardEvent): Readonly<boolean>;
    /**
     * Returns a true shortcut key from the "true-shortcut" attribute.
     * If there is no true shortcut, this function will derive a shortcut key from
     * the false shortcut key if a false shortcut key is defined without a true
     * shortcut key.
     */
    private deriveTrueShortcutKey;
    /**
     * Returns a false shortcut key from the "false-shortcut" attribute.
     * If there is no true shortcut, this function will derive a shortcut key from
     * the true shortcut key if a true shortcut key is defined without a false
     * shortcut key.
     */
    private deriveFalseShortcutKey;
    private isShortcutUppercase;
    private isTrueShortcutKey;
    private isFalseShortcutKey;
    private decisionButtonTemplate;
    render(): TemplateResult<1>;
}
