import { LitElement, PropertyValues, TemplateResult } from "lit";
import { Decision, DecisionOptions } from "../../models/decisions/decision";
import { VerificationGridComponent, VerificationGridInjector } from "../verification-grid/verification-grid";
import { ClassificationComponent } from "./classification/classification";
import { VerificationComponent } from "./verification/verification";
import { KeyboardShortcut } from "../../templates/keyboardShortcut";
interface DecisionContent {
    value: Decision[];
}
export interface DecisionModels<T extends Decision> {
    [DecisionOptions.TRUE]: T;
    [DecisionOptions.FALSE]: T;
    [DecisionOptions.UNSURE]: T;
    [DecisionOptions.SKIP]: T;
}
export type DecisionEvent = CustomEvent<DecisionContent>;
export type DecisionComponentUnion = DecisionComponent | VerificationComponent | ClassificationComponent;
declare const DecisionComponent_base: new (...args: any[]) => LitElement;
/**
 * @description
 * A common abstract decision component that can be implemented by different
 * types of decisions.
 * e.g. a verification decision or a classification decision
 *
 * @event decision
 */
export declare abstract class DecisionComponent extends DecisionComponent_base {
    static styles: import("lit").CSSResult[];
    static readonly decisionEventName: "decision";
    protected abstract handleShortcutKey(event: KeyboardEvent): void;
    protected abstract isShortcutKey(event: KeyboardEvent): Readonly<boolean>;
    protected injector: VerificationGridInjector;
    /** Disables the decision button and prevents decision events from firing */
    disabled: boolean;
    /**
     * Toggles the decision button in and out of mobile compatibility
     * when decision buttons are rendered in a mobile context, they should be
     * larger, and without shortcut keys
     */
    isMobile: boolean;
    verificationGrid?: VerificationGridComponent;
    abstract get decisionModels(): Partial<DecisionModels<Decision>>;
    private shouldEmitNext;
    private keyboardHeldDown;
    private keyUpHandler;
    private keyDownHandler;
    connectedCallback(): void;
    disconnectedCallback(): void;
    willUpdate(change: PropertyValues<this>): void;
    shortcutKeys(): KeyboardShortcut[];
    protected emitDecision(value: Decision[]): void;
    private handleKeyUp;
    private handleKeyDown;
    abstract render(): TemplateResult;
}
declare global {
    interface HTMLElementTagNameMap {
        "oe-decision": DecisionComponent;
    }
}
export {};
