import { LitElement, PropertyValues, TemplateResult } from "lit";
/**
 * Specifies where you should be able to find a preference setting in the media
 * controls that can change the spectrogram settings.
 *
 * @example
 * To move the spectrogram color preferences to the overflow menu:
 * ```html
 * <oe-media-controls color-preference="overflow"></oe-media-controls>
 * ```
 *
 * @value default - Uses sane defaults for the preference positions
 * @value toolbar - The preference can be changed directly from the toolbar
 *                  Warning: If the preference is not shown in the toolbar by
 *                  default it is because the icon is not very intuitive.
 *                  If you want to change, the icon use the template slots
 * @value overflow - The preference can be changed through the overflow (cog icon) menu
 * @value hidden - The preference cannot be changed through the media controls
 */
type PreferenceLocation = "default" | "toolbar" | "overflow" | "hidden";
declare const MediaControlsComponent_base: new (...args: any[]) => LitElement;
/**
 * A simple media player with play/pause and seek functionality that can be used with the open ecoacoustics spectrograms and components.
 *
 * @csspart play-icon - Styling applied to the play icon (including default)
 * @csspart pause-icon - Styling applied to the pause icon (including default)
 *
 * @slot play-icon - The icon to display when the media is stopped
 * @slot pause-icon - The icon to display when the media is playing
 */
export declare class MediaControlsComponent extends MediaControlsComponent_base {
    static styles: import("lit").CSSResult;
    static readonly playShortcut = " ";
    private static recursiveAxesSearch;
    /** A DOM selector to target the spectrogram element */
    for: string;
    playIconPosition: PreferenceLocation;
    private logger;
    private axesElement?;
    private spectrogramElement?;
    private playHandler;
    private keyDownHandler;
    private optionsChangeHandler;
    disconnectedCallback(): void;
    toggleAudio(keyboardShortcut?: boolean): void;
    isSpectrogramPlaying(): boolean;
    protected willUpdate(changedProperties: PropertyValues<this>): void;
    private handleSpectrogramOptionsChange;
    private handlePointerDown;
    private handleKeyDown;
    private handleUpdatePlaying;
    private playIcon;
    private pauseIcon;
    private discreteSettingsTemplate;
    private rangeSettingsTemplate;
    private settingsTemplate;
    render(): TemplateResult<1>;
}
declare global {
    interface HTMLElementTagNameMap {
        "oe-media-controls": MediaControlsComponent;
    }
}
export {};
