import { LitElement, TemplateResult } from "lit";
import { SubjectWrapper } from "../../models/subject";
import { Decision } from "../../models/decisions/decision";
import { Tag } from "../../models/tag";
export declare const requiredVerificationPlaceholder: unique symbol;
export type RequiredVerification = typeof requiredVerificationPlaceholder;
export type RequiredClassification = Tag;
export type RequiredDecision = RequiredVerification | RequiredClassification;
export type OverflowEvent = CustomEvent<OverflowEventDetail>;
interface OverflowEventDetail {
    isOverlapping: boolean;
}
declare const VerificationGridTileComponent_base: new (...args: any[]) => LitElement;
/**
 * @description
 * A component to scope ids to a template inside a shadow DOM
 * This component will be used by the verification-grid component but will
 * probably not be used by users
 * It can also manage the selection state
 *
 * @slot - The template to be rendered inside the grid tile
 *
 * @cssproperty [--decision-color] - The border color that is applied when a
 * decision is being shown
 * @cssproperty [--selected-border-size] - The size of the border when a
 * decision is being shown
 *
 * @event Loaded
 */
export declare class VerificationGridTileComponent extends VerificationGridTileComponent_base {
    static styles: import("lit").CSSResult[];
    static readonly selectedEventName = "selected";
    model: SubjectWrapper;
    private settings;
    private injector;
    /**
     * Hides a grid tile. This is useful for virtual paging so if you have a
     * grid of tiles where not all have a source, you can hide the ones that
     * do not have a source instead of destroying them completely as they might
     * be used in the future when paging back in history or the grid size is
     * increased.
     */
    hidden: boolean;
    showKeyboardShortcuts: boolean;
    selected: boolean;
    /**
     * The index position of the tile within a verification grid that is used
     * to determine the selection keyboard shortcut associated with the grid tile
     */
    index: number;
    readonly requiredDecisions: RequiredDecision[];
    isOverlapping: boolean;
    private spectrogram;
    private slotWrapper;
    private contentsWrapper;
    private keyDownHandler;
    private loadingHandler;
    private loadedHandler;
    loaded: boolean;
    private shortcuts;
    private intersectionObserver;
    connectedCallback(): void;
    disconnectedCallback(): void;
    firstUpdated(): void;
    willUpdate(): void;
    resetSettings(): void;
    addDecision(decision: Decision): void;
    removeDecision(decision: Decision): void;
    private hasAlternativeShortcut;
    private handleIntersection;
    private handleLoading;
    private handleLoaded;
    private handleFocusedKeyDown;
    private handleKeyDown;
    private dispatchSelectedEvent;
    private keyboardShortcutTemplate;
    private classificationMeterTemplate;
    private verificationMeterTemplate;
    private meterSegmentTemplate;
    private progressMeterTemplate;
    render(): TemplateResult<1>;
}
declare global {
    interface HTMLElementTagNameMap {
        "oe-verification-grid-tile": VerificationGridTileComponent;
    }
}
export {};
