import { Signal } from "@lit-labs/preact-signals";
import { VerificationGridComponent } from "../../components/verification-grid/verification-grid";
export interface GridShape {
    rows: number;
    columns: number;
}
export declare class DynamicGridSizeController<Container extends HTMLElement> {
    constructor(container: Container, targetElement: VerificationGridComponent, isOverlapping: Signal<boolean>);
    private targetElement;
    private candidateShapes;
    private containerSize;
    private minimumGridCellSize;
    private anyOverlap;
    private target;
    /**
     * Generates a list of candidates for the target and applies the most optimal
     * candidate.
     *
     * If the candidate does not fit, the intersection handler will be called to
     * try the next candidate.
     */
    setTarget(target: number): void;
    /**
     * Re-generates possible candidates for the new container size
     * and applies the most optimal candidate.
     */
    private handleResize;
    private handleIntersection;
    private applyNextCandidateShape;
    /**
     * @returns
     * The first candidate shape that is viable.
     * Viability means that we have determined that it will fit in the container
     * and that it hasn't overflowed in the past.
     */
    private nextCandidateShape;
    private generateSearchTargetBuffer;
    /**
     * Returns all the possible grid shapes that can be used to create a grid of
     * the target size.
     * This function does not check if the grid shape will fit in the container.
     */
    private candidateShapesForTarget;
    /**
     * Sorts the grid shape candidates by two conditions:
     * 1. The distance from the target grid size
     * 2. The similarity between the grid aspect ratio and the container aspect ratio
     */
    private sortByEligibility;
    private static closestDistance;
    private static cosineDistance;
    private setGridShape;
    /**
     * @returns
     * A boolean that represents if the cells in the proposed grid shape meet
     * the minimum cell size requirements.
     */
    private validateShapeCellSize;
    /**
     * @returns
     * A size object that represents the size of a cell in a proposed grid shape
     */
    private gridCellSizeForShape;
}
