export interface QueryDeeplyAssignedElementsOptions {
    selector: string;
    slot?: string;
}
export interface QueryParentElementsOptions {
    selector: string;
    root?: HTMLElement;
}
/**
 * @example
 * ```ts
 * @queryDeeplyAssignedElements("#element-id", "slot-name")
 * public element: Element;
 * ```
 */
export declare function queryDeeplyAssignedElement<T extends Element = Element>(options: QueryDeeplyAssignedElementsOptions): (target: unknown, propertyKey: string) => void;
/**
 * @example
 * ```ts
 * @queryDeeplyAssignedElements(".element-id", "slot-name")
 * public elements: Element[];
 * ```
 */
export declare function queryAllDeeplyAssignedElements<T extends Element = Element>(options: QueryDeeplyAssignedElementsOptions): (target: unknown, propertyKey: string) => void;
/**
 * @description
 * Recursively queries the parent element of the current element until it
 * reaches the selector that matches the query.
 * If no element is found, null will be returned.
 */
export declare function queryParentElement(options: QueryParentElementsOptions): (target: unknown, propertyKey: string) => void;
/**
 * @description
 * Makes a property/attribute required, and will throw an error if the property
 * is not set.
 *
 * @example
 * ```ts
 * @required()
 * @property({ type: String })
 * public name!: string;
 * ```
 *
 * @throws {Error} If the property is not set.
 */
export declare function required(): (target: any, propertyKey: string) => void;
