import { Subject, SubjectWrapper } from "../models/subject";
import { UrlTransformer } from "./subjectParser";
export interface IPageFetcherResponse<T> {
    subjects: Subject[];
    context: T;
    totalItems: number;
}
/**
 * A context object that is passed to the page fetcher function after every call
 * this can be used to keep track of state such as the current page, where the
 * page fetcher would increment the page number after every call.
 */
export type PageFetcherContext = Record<string, unknown>;
export type PageFetcher<T extends PageFetcherContext = any> = ((context: T) => Promise<IPageFetcherResponse<T>>) & {
    brand?: symbol;
};
export type SubjectAppender = (value: SubjectWrapper[]) => void;
export declare class GridPageFetcher {
    constructor(pagingCallback: PageFetcher, urlTransformer: UrlTransformer, subjectQueue: ReadonlyArray<SubjectWrapper>, appender: SubjectAppender);
    totalItems?: number;
    private pagingCallback;
    private urlTransformer;
    private subjectQueue;
    private appender;
    private pagingContext;
    private clientCacheLength;
    private serverCacheLength;
    populateSubjects(decisionHead: number): Promise<void>;
    refreshCache(decisionHead: number): Promise<void>;
    private audioCacheClient;
    private audioCacheServer;
    private fetchNextPage;
}
