import { Subject } from "../models/subject";
/**
 * @description
 * Fetches a remote data source such has a CSV, TSV, JSON file
 * and always return a JSON object.
 *
 * This class can also be used to parse files provided by the local file system
 * picker API by converting the selected file into a data URL.
 */
export declare class UrlSourcedFetcher {
    static readonly brand: unique symbol;
    private static readonly unsupportedFormatError;
    private static readonly undeterminedFormatError;
    get src(): string;
    file?: File;
    private _src;
    /**
     * returns the IANA media type as defined by
     * https://www.iana.org/assignments/media-types/media-types.xhtml
     *
     * You should always trust this getter over the file objects type because
     * the file object can be incomplete or incorrect
     */
    get mediaType(): string;
    updateSrc(newSource: string | File): Promise<typeof this>;
    generateSubjects(): Promise<Subject[]>;
    /**
     * Attempts to extract the MIME media type using the file extension
     * This should always be used as a last resort for when the browser cannot
     * determine the correct MIME type.
     */
    private fileExtensionMediaType;
}
